@@ -39,7 +39,7 @@ class Exceptions:
 
 class WorkMailMessageFlowClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html)
     """
 
@@ -48,7 +48,7 @@ class WorkMailMessageFlowClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#can_paginate)
         """
 
@@ -60,20 +60,20 @@ class WorkMailMessageFlowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#generate_presigned_url)
         """
 
-    def get_raw_message_content(self, *, messageId: str) -> GetRawMessageContentResponseTypeDef:
+    def get_raw_message_content(self, messageId: str) -> GetRawMessageContentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#get_raw_message_content)
         """
 
     def put_raw_message_content(
-        self, *, messageId: str, content: RawMessageContentTypeDef
+        self, messageId: str, content: RawMessageContentTypeDef
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workmailmessageflow/client.html#put_raw_message_content)
         """
